@@ -1555,7 +1555,7 @@ class ApertureStats:
         covar = self._covariance
         orient_radians = 0.5 * np.arctan2(2.0 * covar[:, 0, 1],
                                           (covar[:, 0, 0] - covar[:, 1, 1]))
-        return orient_radians * 180.0 / np.pi * u.deg
+        return np.rad2deg(orient_radians) * u.deg
 
     @lazyproperty
     @as_scalar
