@@ -35,6 +35,7 @@ class LocalBackground:
         `~photutils.background.MedianBackground` with sigma clipping
         (i.e., sigma-clipped median).
     """
+
     def __init__(self, inner_radius, outer_radius,
                  bkg_estimator=MedianBackground()):
         self.inner_radius = inner_radius
@@ -72,7 +73,7 @@ class LocalBackground:
         x = np.atleast_1d(x)
         y = np.atleast_1d(y)
 
-        self._aperture.positions = np.array(list(zip(x, y)))
+        self._aperture.positions = np.array(list(zip(x, y, strict=True)))
         apermasks = self._aperture.to_mask(method='center')
 
         bkg = []
