@@ -3,4 +3,5 @@
 This subpackage contains tools for centroiding sources.
 """
 
-from .core import *  # noqa
+from .core import *  # noqa: F401, F403
+from .gaussian import *  # noqa: F401, F403
