@@ -3,9 +3,9 @@
 Tests for the core module.
 """
 
-import itertools
 from contextlib import nullcontext
 
+import astropy.units as u
 import numpy as np
 import pytest
 from astropy.modeling.models import Gaussian2D
@@ -16,50 +16,66 @@ from photutils.centroids.core import (centroid_com, centroid_quadratic,
                                       centroid_sources)
 from photutils.centroids.gaussian import centroid_1dg, centroid_2dg
 from photutils.datasets import make_4gaussians_image, make_noise_image
-from photutils.utils._optional_deps import HAS_SCIPY
 
-XCEN = 25.7
-YCEN = 26.2
-XSTDS = [3.2, 4.0]
-YSTDS = [5.7, 4.1]
-THETAS = np.array([30.0, 45.0]) * np.pi / 180.0
 
-DATA = np.zeros((3, 3))
-DATA[0:2, 1] = 1.0
-DATA[1, 0:2] = 1.0
-DATA[1, 1] = 2.0
+@pytest.fixture(name='test_simple_data')
+def fixture_test_simple_data():
+    xcen = 25.7
+    ycen = 26.2
+    data = np.zeros((3, 3))
+    data[0:2, 1] = 1.0
+    data[1, 0:2] = 1.0
+    data[1, 1] = 2.0
+    return data, xcen, ycen
 
-CENTROID_FUNCS = (centroid_com, centroid_quadratic, centroid_1dg,
-                  centroid_2dg)
+
+@pytest.fixture(name='test_data')
+def fixture_test_data():
+    ysize = 50
+    xsize = 47
+    yy, xx = np.mgrid[0:ysize, 0:xsize]
+    data = np.zeros((ysize, xsize))
+    xpos = (1, 25, 25, 35, 46)
+    ypos = (1, 25, 12, 35, 49)
+    for xc, yc in zip(xpos, ypos, strict=True):
+        model = Gaussian2D(10.0, xc, yc, x_stddev=2, y_stddev=2,
+                           theta=0)
+        data += model(xx, yy)
+    return data, xpos, ypos
 
 
 # NOTE: the fitting routines in astropy use scipy.optimize
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
-@pytest.mark.parametrize(('x_std', 'y_std', 'theta'),
-                         list(itertools.product(XSTDS, YSTDS, THETAS)))
-def test_centroid_comquad(x_std, y_std, theta):
-    model = Gaussian2D(2.4, XCEN, YCEN, x_stddev=x_std, y_stddev=y_std,
+@pytest.mark.parametrize('x_std', [3.2, 4.0])
+@pytest.mark.parametrize('y_std', [5.7, 4.1])
+@pytest.mark.parametrize('theta', np.deg2rad([30.0, 45.0]))
+@pytest.mark.parametrize('units', [True, False])
+def test_centroid_comquad(test_simple_data, x_std, y_std, theta, units):
+    data, xcen, ycen = test_simple_data
+
+    if units:
+        data = data * u.nJy
+
+    model = Gaussian2D(2.4, xcen, ycen, x_stddev=x_std, y_stddev=y_std,
                        theta=theta)
     y, x = np.mgrid[0:50, 0:47]
     data = model(x, y)
     xc, yc = centroid_com(data)
-    assert_allclose((xc, yc), (XCEN, YCEN), rtol=0, atol=1.0e-3)
+    assert_allclose((xc, yc), (xcen, ycen), rtol=0, atol=1.0e-3)
 
     xc, yc = centroid_quadratic(data)
-    assert_allclose((xc, yc), (XCEN, YCEN), rtol=0, atol=0.015)
+    assert_allclose((xc, yc), (xcen, ycen), rtol=0, atol=0.015)
 
     # test with mask
     mask = np.zeros(data.shape, dtype=bool)
     data[10, 10] = 1.0e5
     mask[10, 10] = True
     xc, yc = centroid_com(data, mask=mask)
-    assert_allclose((xc, yc), (XCEN, YCEN), rtol=0, atol=1.0e-3)
+    assert_allclose((xc, yc), (xcen, ycen), rtol=0, atol=1.0e-3)
 
     xc, yc = centroid_quadratic(data, mask=mask)
-    assert_allclose((xc, yc), (XCEN, YCEN), rtol=0, atol=0.015)
+    assert_allclose((xc, yc), (xcen, ycen), rtol=0, atol=0.015)
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 @pytest.mark.parametrize('use_mask', [True, False])
 def test_centroid_comquad_nan_withmask(use_mask):
     xc_ref = 24.7
@@ -76,8 +92,8 @@ def test_centroid_comquad_nan_withmask(use_mask):
     else:
         mask = None
         nwarn = 1
-        ctx = pytest.warns(AstropyUserWarning,
-                           match='Input data contains non-finite values')
+        match = 'Input data contains non-finite values'
+        ctx = pytest.warns(AstropyUserWarning, match=match)
 
     with ctx as warnlist:
         xc, yc = centroid_com(data, mask=mask)
@@ -113,11 +129,11 @@ def test_centroid_com_allmask():
 def test_centroid_com_invalid_inputs():
     data = np.zeros((4, 4))
     mask = np.zeros((2, 2), dtype=bool)
-    with pytest.raises(ValueError):
+    match = 'data and mask must have the same shape'
+    with pytest.raises(ValueError, match=match):
         centroid_com(data, mask=mask)
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_centroid_quadratic_xypeak():
     data = np.zeros((11, 11))
     data[5, 5] = 100
@@ -134,15 +150,17 @@ def test_centroid_quadratic_xypeak():
                                 search_boxsize=5)
     assert_allclose(xycen3, (7, 7))
 
-    with pytest.raises(ValueError):
+    match = 'xpeak is outside of the input data'
+    with pytest.raises(ValueError, match=match):
         centroid_quadratic(data, xpeak=15, ypeak=5)
-    with pytest.raises(ValueError):
+    match = 'ypeak is outside of the input data'
+    with pytest.raises(ValueError, match=match):
         centroid_quadratic(data, xpeak=5, ypeak=15)
-    with pytest.raises(ValueError):
+    match = 'xpeak is outside of the input data'
+    with pytest.raises(ValueError, match=match):
         centroid_quadratic(data, xpeak=15, ypeak=15)
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_centroid_quadratic_nan():
     gmodel = Gaussian2D(42.1, 47.8, 52.4, 4.7, 4.7, 0)
     yy, xx = np.mgrid[0:100, 0:100]
@@ -156,37 +174,38 @@ def test_centroid_quadratic_nan():
     assert_allclose(xycen, [47.58324, 51.827182])
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_centroid_quadratic_npts():
     data = np.zeros((3, 3))
     data[1, 1] = 1
     mask = np.zeros(data.shape, dtype=bool)
     mask[0, :] = True
     mask[2, :] = True
-    with pytest.warns(AstropyUserWarning,
-                      match='at least 6 unmasked data points'):
+    match = 'at least 6 unmasked data points'
+    with pytest.warns(AstropyUserWarning, match=match):
         centroid_quadratic(data, mask=mask)
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_centroid_quadratic_invalid_inputs():
     data = np.zeros((4, 4))
     mask = np.zeros((2, 2), dtype=bool)
-    with pytest.raises(ValueError):
+    match = 'xpeak and ypeak must both be input or "None"'
+    with pytest.raises(ValueError, match=match):
         centroid_quadratic(data, xpeak=3, ypeak=None)
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match=match):
         centroid_quadratic(data, xpeak=None, ypeak=3)
-    with pytest.raises(ValueError):
+    match = 'fit_boxsize must have 1 or 2 elements'
+    with pytest.raises(ValueError, match=match):
         centroid_quadratic(data, fit_boxsize=(2, 2, 2))
-    with pytest.raises(ValueError):
+    match = 'fit_boxsize must have an odd value for both axes'
+    with pytest.raises(ValueError, match=match):
         centroid_quadratic(data, fit_boxsize=(-2, 2))
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match=match):
         centroid_quadratic(data, fit_boxsize=(2, 2))
-    with pytest.raises(ValueError):
+    match = 'data and mask must have the same shape'
+    with pytest.raises(ValueError, match=match):
         centroid_quadratic(data, mask=mask)
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_centroid_quadratic_edge():
     data = np.zeros((11, 11))
     data[1, 1] = 100
@@ -200,33 +219,18 @@ def test_centroid_quadratic_edge():
 
     data = np.zeros((5, 5))
     data[0, 0] = 100
-    with pytest.warns(AstropyUserWarning,
-                      match='maximum value is at the edge'):
+    match = 'maximum value is at the edge'
+    with pytest.warns(AstropyUserWarning, match=match):
         xycen = centroid_quadratic(data)
     assert_allclose(xycen, (0, 0))
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 class TestCentroidSources:
-    def setup_class(self):
-        ysize = 50
-        xsize = 47
-        yy, xx = np.mgrid[0:ysize, 0:xsize]
-        data = np.zeros((ysize, xsize))
-        xcen = (1, 25, 25, 35, 46)
-        ycen = (1, 25, 12, 35, 49)
-        for xc, yc in zip(xcen, ycen):
-            model = Gaussian2D(10.0, xc, yc, x_stddev=2, y_stddev=2,
-                               theta=0)
-            data += model(xx, yy)
-        self.xpos = xcen
-        self.ypos = ycen
-        self.data = data
 
     @staticmethod
     def test_centroid_sources():
         theta = np.pi / 6.0
-        model = Gaussian2D(2.4, XCEN, YCEN, x_stddev=3.2, y_stddev=5.7,
+        model = Gaussian2D(2.4, 25.7, 26.2, x_stddev=3.2, y_stddev=5.7,
                            theta=theta)
         y, x = np.mgrid[0:50, 0:47]
         data = model(x, y)
@@ -244,51 +248,64 @@ class TestCentroidSources:
         assert_allclose(xc, (25.67,), atol=1e-1)
         assert_allclose(yc, (26.41,), atol=1e-1)
 
-        with pytest.raises(ValueError):
-            centroid_sources(data, 25, [[26]], box_size=11)
-        with pytest.raises(ValueError):
+        match = 'xpos must be a 1D array'
+        with pytest.raises(ValueError, match=match):
             centroid_sources(data, [[25]], 26, box_size=11)
-        with pytest.raises(ValueError):
+        match = 'ypos must be a 1D array'
+        with pytest.raises(ValueError, match=match):
+            centroid_sources(data, 25, [[26]], box_size=11)
+        match = 'box_size must have 1 or 2 elements'
+        with pytest.raises(ValueError, match=match):
             centroid_sources(data, 25, 26, box_size=(1, 2, 3))
-        with pytest.raises(ValueError):
+        match = 'box_size or footprint must be defined'
+        with pytest.raises(ValueError, match=match):
             centroid_sources(data, 25, 26, box_size=None, footprint=None)
-        with pytest.raises(ValueError):
+        match = 'footprint must be a 2D array'
+        with pytest.raises(ValueError, match=match):
             centroid_sources(data, 25, 26, footprint=np.ones((3, 3, 3)))
 
         def test_func(data):
             return data
 
-        with pytest.raises(ValueError):
+        match = 'The input "centroid_func" must have a "mask" keyword'
+        with pytest.raises(ValueError, match=match):
             centroid_sources(data, [25], 26, centroid_func=test_func)
 
-    @pytest.mark.parametrize('centroid_func', CENTROID_FUNCS)
-    def test_xypos(self, centroid_func):
-        with pytest.raises(ValueError):
-            centroid_sources(self.data, 47, 50, box_size=5,
+    @pytest.mark.parametrize('centroid_func', [centroid_com,
+                                               centroid_quadratic,
+                                               centroid_1dg, centroid_2dg])
+    def test_xypos(self, test_data, centroid_func):
+        data = test_data[0]
+        match = 'xpos, ypos values contains points outside of input data'
+        with pytest.raises(ValueError, match=match):
+            centroid_sources(data, 47, 50, box_size=5,
                              centroid_func=centroid_func)
 
-    def test_gaussian_fits_npts(self):
-        xcen, ycen = centroid_sources(self.data, self.xpos, self.ypos,
-                                      box_size=3, centroid_func=centroid_1dg)
-        assert_allclose(xcen, np.full(5, np.nan))
-        assert_allclose(ycen, np.full(5, np.nan))
+    def test_gaussian_fits_npts(self, test_data):
+        data, xpos, ypos = test_data
+        xcen, ycen = centroid_sources(data, xpos, ypos, box_size=3,
+                                      centroid_func=centroid_1dg)
 
-        xcen, ycen = centroid_sources(self.data, self.xpos, self.ypos,
-                                      box_size=3, centroid_func=centroid_2dg)
-        xres = np.copy(self.xpos).astype(float)
-        yres = np.copy(self.ypos).astype(float)
+        xres = np.copy(xpos).astype(float)
+        yres = np.copy(ypos).astype(float)
+        xres[-1] = 46.689208
+        yres[-1] = 49.689208
+        assert_allclose(xcen, xres)
+        assert_allclose(ycen, yres)
+
+        xcen, ycen = centroid_sources(data, xpos, ypos, box_size=3,
+                                      centroid_func=centroid_2dg)
         xres[-1] = np.nan
         yres[-1] = np.nan
         assert_allclose(xcen, xres)
         assert_allclose(ycen, yres)
 
-        xcen, ycen = centroid_sources(self.data, self.xpos, self.ypos,
-                                      box_size=5, centroid_func=centroid_1dg)
-        assert_allclose(xcen, xres)
-        assert_allclose(ycen, yres)
+        xcen, ycen = centroid_sources(data, xpos, ypos, box_size=5,
+                                      centroid_func=centroid_1dg)
+        assert_allclose(xcen, xpos)
+        assert_allclose(ycen, ypos)
 
-        xcen, ycen = centroid_sources(self.data, self.xpos, self.ypos,
-                                      box_size=3,
+        xcen, ycen = centroid_sources(data, xpos, ypos, box_size=3,
                                       centroid_func=centroid_quadratic)
         assert_allclose(xcen, xres)
         assert_allclose(ycen, yres)
@@ -340,34 +357,37 @@ class TestCentroidSources:
         assert ~np.any(np.isnan(data))
         assert_allclose(xycen, (xc_ref, yc_ref), atol=0.01)
 
-    def test_mask(self):
-        xcen1, ycen1 = centroid_sources(self.data, 25, 23, box_size=(55, 55))
+    def test_mask(self, test_data):
+        data = test_data[0]
+        xcen1, ycen1 = centroid_sources(data, 25, 23, box_size=(55, 55))
 
-        mask = np.zeros(self.data.shape, dtype=bool)
+        mask = np.zeros(data.shape, dtype=bool)
         mask[0, 0] = True
         mask[24, 24] = True
         mask[11, 24] = True
-        xcen2, ycen2 = centroid_sources(self.data, 25, 23,
-                                        box_size=(55, 55), mask=mask)
+        xcen2, ycen2 = centroid_sources(data, 25, 23, box_size=(55, 55),
+                                        mask=mask)
         assert not np.allclose(xcen1, xcen2)
         assert not np.allclose(ycen1, ycen2)
 
-    def test_error_none(self):
-        xycen1 = centroid_sources(self.data, xpos=25, ypos=25, error=None,
+    def test_error_none(self, test_data):
+        data = test_data[0]
+        xycen1 = centroid_sources(data, xpos=25, ypos=25, error=None,
                                   centroid_func=centroid_1dg)
-        xycen2 = centroid_sources(self.data, xpos=25, ypos=25, error=None,
+        xycen2 = centroid_sources(data, xpos=25, ypos=25, error=None,
                                   centroid_func=centroid_2dg)
         assert_allclose(xycen1, ([25], [25]), atol=1.0e-3)
         assert_allclose(xycen2, ([25], [25]), atol=1.0e-3)
 
-    def test_xypeaks_none(self):
-        xycen1 = centroid_sources(self.data, xpos=25, ypos=25, error=None,
+    def test_xypeaks_none(self, test_data):
+        data = test_data[0]
+        xycen1 = centroid_sources(data, xpos=25, ypos=25, error=None,
                                   xpeak=None, ypeak=25,
                                   centroid_func=centroid_quadratic)
-        xycen2 = centroid_sources(self.data, xpos=25, ypos=25, error=None,
+        xycen2 = centroid_sources(data, xpos=25, ypos=25, error=None,
                                   xpeak=25, ypeak=None,
                                   centroid_func=centroid_quadratic)
-        xycen3 = centroid_sources(self.data, xpos=25, ypos=25, error=None,
+        xycen3 = centroid_sources(data, xpos=25, ypos=25, error=None,
                                   xpeak=None, ypeak=None,
                                   centroid_func=centroid_quadratic)
         assert_allclose(xycen1, ([25], [25]), atol=1.0e-3)
@@ -382,16 +402,17 @@ def test_cutout_mask():
     data = make_4gaussians_image()
     x_init = (25, 91, 151, 160)
     y_init = (40, 61, 24, 71)
-    with pytest.raises(ValueError):
-        footprint = np.zeros((3, 3))
+    footprint = np.zeros((3, 3))
+    match = 'is completely masked'
+    with pytest.raises(ValueError, match=match):
         _ = centroid_sources(data, x_init, y_init, footprint=footprint,
                              centroid_func=centroid_com)
 
-    with pytest.raises(ValueError):
-        footprint = np.zeros(data.shape, dtype=bool)
+    footprint = np.zeros(data.shape, dtype=bool)
+    with pytest.raises(ValueError, match=match):
         _ = centroid_sources(data, x_init, y_init, footprint=footprint,
                              centroid_func=centroid_com)
 
-    with pytest.raises(ValueError):
-        mask = np.ones(data.shape, dtype=bool)
+    mask = np.ones(data.shape, dtype=bool)
+    with pytest.raises(ValueError, match=match):
         _ = centroid_sources(data, x_init, y_init, box_size=11, mask=mask)
