@@ -5,6 +5,7 @@ from a list of isophotes.
 """
 
 import numpy as np
+from scipy.interpolate import LSQUnivariateSpline
 
 from photutils.isophote.geometry import EllipseGeometry
 
@@ -49,7 +50,8 @@ def build_ellipse_model(shape, isolist, fill=0.0, high_harmonics=False):
     result : 2D `~numpy.ndarray`
         The image with the model galaxy.
     """
-    from scipy.interpolate import LSQUnivariateSpline
+    if len(isolist) == 0:
+        raise ValueError('isolist must not be empty')
 
     # the target grid is spaced in 0.1 pixel intervals so as
     # to ensure no gaps will result on the output array.
@@ -121,7 +123,7 @@ def build_ellipse_model(shape, isolist, fill=0.0, high_harmonics=False):
                 harm = (a3_array[index] * np.sin(3.0 * phi)
                         + b3_array[index] * np.cos(3.0 * phi)
                         + a4_array[index] * np.sin(4.0 * phi)
-                        + b4_array[index] * np.cos(4.0 * phi)) / 4.0
+                        + b4_array[index] * np.cos(4.0 * phi))
 
             # get image coordinates of (r, phi) pixel
             x = r * np.cos(phi + pa) + x0
