@@ -16,7 +16,6 @@ from photutils.isophote.integrator import MEAN
 from photutils.isophote.isophote import Isophote
 from photutils.isophote.sample import CentralEllipseSample, EllipseSample
 from photutils.isophote.tests.make_test_data import make_test_image
-from photutils.utils._optional_deps import HAS_SCIPY
 
 DATA = make_test_image(seed=0)
 DEFAULT_POS = 256
@@ -35,13 +34,11 @@ def test_gradient():
     assert_allclose(sample.sector_area, 2.00, atol=0.01)
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_fitting_raw():
     """
     This test performs a raw (no EllipseFitter), 1-step correction in
     one single ellipse coefficient.
     """
-
     # pick first guess ellipse that is off in just
     # one of the parameters (eps).
     sample = EllipseSample(DATA, 40.0, eps=2 * 0.2)
@@ -64,7 +61,6 @@ def test_fitting_raw():
     assert_allclose(new_eps, 0.21, atol=0.01)
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_fitting_small_radii():
     sample = EllipseSample(DATA, 2.0)
     fitter = EllipseFitter(sample)
@@ -74,7 +70,6 @@ def test_fitting_small_radii():
     assert isophote.ndata == 13
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_fitting_eps():
     # initial guess is off in the eps parameter
     sample = EllipseSample(DATA, 40.0, eps=2 * 0.2)
@@ -87,7 +82,6 @@ def test_fitting_eps():
     assert g.eps <= 0.21
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_fitting_pa():
     data = make_test_image(pa=np.pi / 4, noise=0.01, seed=0)
 
@@ -101,7 +95,6 @@ def test_fitting_pa():
     assert g.pa <= (np.pi / 4 + 0.05)
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_fitting_xy():
     pos = DEFAULT_POS - 5
     data = make_test_image(x0=pos, y0=pos, seed=0)
@@ -118,7 +111,6 @@ def test_fitting_xy():
     assert g.y0 <= (pos + 1)
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_fitting_all():
     # build test image that is off from the defaults
     # assumed by the EllipseSample constructor.
@@ -156,7 +148,6 @@ def test_fitting_all():
 
 
 @pytest.mark.remote_data
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 class TestM51:
     def setup_class(self):
         path = get_path('isophote/M51.fits', location='photutils-datasets',
@@ -166,16 +157,10 @@ class TestM51:
         hdu.close()
 
     def test_m51(self):
-        # here we evaluate the detailed convergence behavior
+        # Here we evaluate the detailed convergence behavior
         # for a particular ellipse where we can see the eps
         # parameter jumping back and forth.
-        # sample = EllipseSample(self.data, 13.31000001, eps=0.16,
-        #                        position_angle=((-37.5+90)/180.*np.pi))
-        # sample.update()
-        # fitter = EllipseFitter(sample)
-        # isophote = fitter.fit()
-
-        # we start the fit with initial values taken from
+        # We start the fit with initial values taken from
         # previous isophote, as determined by the old code.
 
         # sample taken in high SNR region
@@ -212,7 +197,8 @@ class TestM51:
         # this code finds central x and y offset by about 0.1 pixel wrt the
         # spp code. In here we use as input the position computed by this
         # code, thus this test is checking just the extraction algorithm.
-        g = EllipseGeometry(257.02, 258.1, 0.0, 0.0, 0.0, 0.1, False)
+        g = EllipseGeometry(257.02, 258.1, 0.0, 0.0, 0.0, 0.1,
+                            linear_growth=False)
         sample = CentralEllipseSample(self.data, 0.0, geometry=g)
         fitter = CentralEllipseFitter(sample)
         isophote = fitter.fit()
