@@ -7,13 +7,14 @@ structures to hold the cutouts for fitting and building ePSFs.
 import warnings
 
 import numpy as np
-from astropy.nddata import NDData
+from astropy.nddata import NDData, StdDevUncertainty
 from astropy.nddata.utils import NoOverlapError, PartialOverlapError
 from astropy.table import Table
 from astropy.utils import lazyproperty
 from astropy.utils.exceptions import AstropyUserWarning
 
 from photutils.aperture import BoundingBox
+from photutils.psf.image_models import _LegacyEPSFModel
 from photutils.psf.utils import _interpolate_missing_data
 from photutils.utils._parameters import as_pair
 from photutils.utils.cutouts import _overlap_slices as overlap_slices
@@ -102,7 +103,9 @@ class EPSFStar:
 
     @property
     def data(self):
-        """The 2D cutout image."""
+        """
+        The 2D cutout image.
+        """
         return self._data
 
     @property
@@ -117,10 +120,9 @@ class EPSFStar:
     def cutout_center(self, value):
         if value is None:
             value = ((self.shape[1] - 1) / 2.0, (self.shape[0] - 1) / 2.0)
-        else:
-            if len(value) != 2:
-                raise ValueError('The "cutout_center" attribute must have '
-                                 'two elements in (x, y) form.')
+        elif len(value) != 2:
+            raise ValueError('The "cutout_center" attribute must have '
+                             'two elements in (x, y) form.')
 
         self._cutout_center = np.asarray(value)
 
@@ -157,6 +159,11 @@ class EPSFStar:
 
         Missing data is filled in by interpolation to better estimate
         the total flux.
+
+        Returns
+        -------
+        flux : float
+            The estimated star's flux.
         """
         if np.any(self.mask):
             data_interp = _interpolate_missing_data(self.data, method='cubic',
@@ -177,7 +184,7 @@ class EPSFStar:
 
         Parameters
         ----------
-        epsf : `EPSFModel`
+        epsf : `ImagePSF`
             The ePSF to register.
 
         Returns
@@ -185,11 +192,17 @@ class EPSFStar:
         data : `~numpy.ndarray`
             A 2D array of the registered/scaled ePSF.
         """
+        legacy_epsf = _LegacyEPSFModel(epsf.data, flux=epsf.flux, x_0=epsf.x_0,
+                                       y_0=epsf.y_0,
+                                       oversampling=epsf.oversampling,
+                                       fill_value=epsf.fill_value)
+
         yy, xx = np.indices(self.shape, dtype=float)
         xx = xx - self.cutout_center[0]
         yy = yy - self.cutout_center[1]
 
-        return self.flux * epsf.evaluate(xx, yy, flux=1.0, x_0=0.0, y_0=0.0)
+        return self.flux * legacy_epsf.evaluate(xx, yy, flux=1.0, x_0=0.0,
+                                                y_0=0.0)
 
     def compute_residual_image(self, epsf):
         """
@@ -198,7 +211,7 @@ class EPSFStar:
 
         Parameters
         ----------
-        epsf : `EPSFModel`
+        epsf : `ImagePSF`
             The ePSF to subtract.
 
         Returns
@@ -251,7 +264,9 @@ class EPSFStar:
 
     @lazyproperty
     def _data_values(self):
-        """1D array of unmasked cutout data values."""
+        """
+        1D array of unmasked cutout data values.
+        """
         return self.data[~self.mask].ravel()
 
     @lazyproperty
@@ -286,8 +301,8 @@ class EPSFStars:
         elif isinstance(stars_list, list):
             self._data = stars_list
         else:
-            raise ValueError('stars_list must be a list of EPSFStar and/or '
-                             'LinkedEPSFStar objects.')
+            raise TypeError('stars_list must be a list of EPSFStar and/or '
+                            'LinkedEPSFStar objects.')
 
     def __len__(self):
         return len(self._data)
@@ -332,10 +347,9 @@ class EPSFStars:
     @property
     def cutout_center_flat(self):
         """
-        A `~numpy.ndarray` of the ``(x, y)`` position of all the
-        stars' centers (including linked stars) with respect to the
-        input cutout ``data`` array, as a 2D array (``n_all_stars`` x
-        2).
+        A `~numpy.ndarray` of the ``(x, y)`` position of all the stars'
+        centers (including linked stars) with respect to the input
+        cutout ``data`` array, as a 2D array (``n_all_stars`` x 2).
 
         Note that when `EPSFStars` contains any `LinkedEPSFStar`, the
         ``cutout_center`` attribute will be a nested 3D array.
@@ -399,8 +413,9 @@ class EPSFStars:
     def n_all_stars(self):
         """
         The total number of `EPSFStar` objects, including all the linked
-        stars within `LinkedEPSFStar`. Each linked star is included in
-        the count.
+        stars within `LinkedEPSFStar`.
+
+        Each linked star is included in the count.
         """
         return len(self.all_stars)
 
@@ -409,7 +424,9 @@ class EPSFStars:
         """
         The total number of `EPSFStar` objects, including all the linked
         stars within `LinkedEPSFStar`, that have not been excluded from
-        fitting. Each non-excluded linked star is included in the count.
+        fitting.
+
+        Each non-excluded linked star is included in the count.
         """
         return len(self.all_good_stars)
 
@@ -442,8 +459,8 @@ class LinkedEPSFStar(EPSFStars):
     def __init__(self, stars_list):
         for star in stars_list:
             if not isinstance(star, EPSFStar):
-                raise ValueError('stars_list must contain only EPSFStar '
-                                 'objects.')
+                raise TypeError('stars_list must contain only EPSFStar '
+                                'objects.')
             if star.wcs_large is None:
                 raise ValueError('Each EPSFStar object must have a valid '
                                  'wcs_large attribute.')
@@ -471,7 +488,8 @@ class LinkedEPSFStar(EPSFStars):
                           'build process.', AstropyUserWarning)
             return
 
-        good_stars = [self._data[i] for i in idx]  # pylint: disable=not-an-iterable
+        good_stars = [self._data[i]
+                      for i in idx]  # pylint: disable=not-an-iterable
 
         coords = []
         for star in good_stars:
@@ -570,13 +588,13 @@ def extract_stars(data, catalogs, *, size=(11, 11)):
 
     for img in data:
         if not isinstance(img, NDData):
-            raise ValueError('data must be a single or list of NDData '
-                             'objects.')
+            raise TypeError('data must be a single NDData or list of NDData '
+                            'objects.')
 
     for cat in catalogs:
         if not isinstance(cat, Table):
-            raise ValueError('catalogs must be a single or list of Table '
-                             'objects.')
+            raise TypeError('catalogs must be a single Table or list of Table '
+                            'objects.')
 
     if len(catalogs) == 1 and len(data) > 1:
         if 'skycoord' not in catalogs[0].colnames:
@@ -613,14 +631,12 @@ def extract_stars(data, catalogs, *, size=(11, 11)):
         if len(data) > 1:
             use_xy = False  # linked stars require skycoord positions
 
-        stars = []
         # stars is a list of lists, one list of stars in each image
-        for img in data:
-            stars.append(_extract_stars(img, catalogs[0], size=size,
-                                        use_xy=use_xy))
+        stars = [_extract_stars(img, catalogs[0], size=size, use_xy=use_xy)
+                 for img in data]
 
         # transpose the list of lists, to associate linked stars
-        stars = list(map(list, zip(*stars)))
+        stars = list(map(list, zip(*stars, strict=True)))
 
         # remove 'None' stars (i.e., no or partial overlap in one or
         # more images) and handle the case of only one "linked" star
@@ -641,7 +657,7 @@ def extract_stars(data, catalogs, *, size=(11, 11)):
             stars_out.append(good_stars)
     else:  # no linked stars
         stars_out = []
-        for img, cat in zip(data, catalogs):
+        for img, cat in zip(data, catalogs, strict=True):
             stars_out.extend(_extract_stars(img, cat, size=size, use_xy=True))
 
         n_input = len(stars_out)
@@ -713,21 +729,25 @@ def _extract_stars(data, catalog, *, size=(11, 11), use_xy=True):
 
     if data.uncertainty is None:
         weights = np.ones_like(data.data)
+    elif data.uncertainty.uncertainty_type == 'weights':
+        weights = np.asanyarray(data.uncertainty.array, dtype=float)
     else:
-        if data.uncertainty.uncertainty_type == 'weights':
-            weights = np.asanyarray(data.uncertainty.array, dtype=float)
-        else:
-            warnings.warn('The data uncertainty attribute has an unsupported '
-                          'type. Only uncertainty_type="weights" can be '
-                          'used to set weights. Weights will be set to 1.',
-                          AstropyUserWarning)
-            weights = np.ones_like(data.data)
+        # other uncertainties are converted to the inverse standard
+        # deviation as the weight; ignore divide-by-zero RuntimeWarning
+        with warnings.catch_warnings():
+            warnings.simplefilter('ignore', RuntimeWarning)
+            weights = data.uncertainty.represent_as(StdDevUncertainty)
+            weights = 1.0 / weights.array
+        if np.any(~np.isfinite(weights)):
+            warnings.warn('One or more weight values is not finite. Please '
+                          'check the input uncertainty values in the input '
+                          'NDData object.', AstropyUserWarning)
 
     if data.mask is not None:
         weights[data.mask] = 0.0
 
     stars = []
-    for xcenter, ycenter, obj_id in zip(xcenters, ycenters, ids):
+    for xcenter, ycenter, obj_id in zip(xcenters, ycenters, ids, strict=True):
         try:
             large_slc, _ = overlap_slices(data.data.shape, size,
                                           (ycenter, xcenter), mode='strict')
