@@ -7,28 +7,26 @@ import itertools
 
 import numpy as np
 import pytest
-from astropy.modeling.fitting import LevMarLSQFitter
-from astropy.nddata import NDData
+from astropy.modeling.fitting import TRFLSQFitter
+from astropy.nddata import (InverseVariance, NDData, StdDevUncertainty,
+                            VarianceUncertainty)
 from astropy.stats import SigmaClip
 from astropy.table import Table
 from astropy.utils.exceptions import AstropyUserWarning
 from numpy.testing import assert_allclose, assert_almost_equal
+from scipy.spatial import cKDTree
 
 from photutils.datasets import make_model_image
 from photutils.psf.epsf import EPSFBuilder, EPSFFitter
 from photutils.psf.epsf_stars import EPSFStars, extract_stars
-from photutils.psf.models import EPSFModel, IntegratedGaussianPRF
-from photutils.utils._optional_deps import HAS_SCIPY
+from photutils.psf.functional_models import CircularGaussianPRF
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 class TestEPSFBuild:
     def setup_class(self):
         """
         Create a simulated image for testing.
         """
-        from scipy.spatial import cKDTree
-
         shape = (750, 750)
 
         # define random star positions
@@ -41,7 +39,7 @@ class TestEPSFBuild:
         # enforce a minimum separation
         min_dist = 25
         coords = [(yy[0], xx[0])]
-        for xxi, yyi in zip(xx, yy):
+        for xxi, yyi in zip(xx, yy, strict=True):
             newcoord = [yyi, xxi]
             dist, _ = cKDTree([newcoord]).query(coords, 1)
             if np.min(dist) > min_dist:
@@ -50,15 +48,15 @@ class TestEPSFBuild:
         zz = rng.uniform(low=0, high=200000, size=len(xx))
 
         # define a table of model parameters
-        self.stddev = 2.0
+        self.fwhm = 4.7
         sources = Table()
         sources['amplitude'] = zz
         sources['x_0'] = xx
         sources['y_0'] = yy
-        sources['sigma'] = np.zeros(len(xx)) + self.stddev
+        sources['fwhm'] = np.zeros(len(xx)) + self.fwhm
         sources['theta'] = 0.0
 
-        psf_model = IntegratedGaussianPRF(sigma=self.stddev)
+        psf_model = CircularGaussianPRF(fwhm=self.fwhm)
         self.data = make_model_image(shape, psf_model, sources)
         self.nddata = NDData(self.data)
 
@@ -69,7 +67,8 @@ class TestEPSFBuild:
 
     def test_extract_stars(self):
         size = 25
-        with pytest.warns(AstropyUserWarning, match='were not extracted'):
+        match = 'were not extracted because their cutout region extended'
+        with pytest.warns(AstropyUserWarning, match=match):
             stars = extract_stars(self.nddata, self.init_stars, size=size)
 
         assert len(stars) == 81
@@ -77,13 +76,49 @@ class TestEPSFBuild:
         assert isinstance(stars[0], EPSFStars)
         assert stars[0].data.shape == (size, size)
 
+    def test_extract_stars_uncertainties(self):
+        rng = np.random.default_rng(0)
+        shape = self.nddata.data.shape
+        error = np.abs(rng.normal(loc=0, scale=1, size=shape))
+        uncertainty1 = StdDevUncertainty(error)
+        uncertainty2 = uncertainty1.represent_as(VarianceUncertainty)
+        uncertainty3 = uncertainty1.represent_as(InverseVariance)
+        ndd1 = NDData(self.nddata.data, uncertainty=uncertainty1)
+        ndd2 = NDData(self.nddata.data, uncertainty=uncertainty2)
+        ndd3 = NDData(self.nddata.data, uncertainty=uncertainty3)
+
+        size = 25
+        match = 'were not extracted because their cutout region extended'
+        with pytest.warns(AstropyUserWarning, match=match):
+            ndd_inputs = (ndd1, ndd2, ndd3)
+
+            outputs = [extract_stars(ndd_input, self.init_stars, size=size)
+                       for ndd_input in ndd_inputs]
+
+            for stars in outputs:
+                assert len(stars) == 81
+                assert isinstance(stars, EPSFStars)
+                assert isinstance(stars[0], EPSFStars)
+                assert stars[0].data.shape == (size, size)
+                assert stars[0].weights.shape == (size, size)
+
+        assert_allclose(outputs[0].weights, outputs[1].weights)
+        assert_allclose(outputs[0].weights, outputs[2].weights)
+
+        match = 'One or more weight values is not finite'
+        with pytest.warns(AstropyUserWarning, match=match):
+            uncertainty = StdDevUncertainty(np.zeros(shape))
+            ndd = NDData(self.nddata.data, uncertainty=uncertainty)
+            stars = extract_stars(ndd, self.init_stars[0:3], size=size)
+
     def test_epsf_build(self):
         """
         This is an end-to-end test of EPSFBuilder on a simulated image.
         """
         size = 25
         oversampling = 4
-        with pytest.warns(AstropyUserWarning, match='were not extracted'):
+        match = 'were not extracted because their cutout region extended'
+        with pytest.warns(AstropyUserWarning, match=match):
             stars = extract_stars(self.nddata, self.init_stars, size=size)
         epsf_builder = EPSFBuilder(oversampling=oversampling, maxiters=15,
                                    progress_bar=False, norm_radius=25,
@@ -96,10 +131,10 @@ class TestEPSFBuild:
         y0 = (ref_size - 1) / 2 / oversampling
         y = np.arange(ref_size, dtype=float) / oversampling
 
-        psf_model = IntegratedGaussianPRF(sigma=self.stddev)
+        psf_model = CircularGaussianPRF(fwhm=self.fwhm)
         z = epsf.data
         x = psf_model.evaluate(y.reshape(-1, 1), y.reshape(1, -1), 1, y0, y0,
-                               self.stddev)
+                               self.fwhm)
         assert_allclose(z, x, rtol=1e-2, atol=1e-5)
 
         resid_star = fitted_stars[0].compute_residual_image(epsf)
@@ -109,7 +144,8 @@ class TestEPSFBuild:
     def test_epsf_fitting_bounds(self):
         size = 25
         oversampling = 4
-        with pytest.warns(AstropyUserWarning, match='were not extracted'):
+        match = 'were not extracted because their cutout region extended'
+        with pytest.warns(AstropyUserWarning, match=match):
             stars = extract_stars(self.nddata, self.init_stars, size=size)
         epsf_builder = EPSFBuilder(oversampling=oversampling, maxiters=8,
                                    progress_bar=True, norm_radius=25,
@@ -118,32 +154,40 @@ class TestEPSFBuild:
                                    smoothing_kernel='quadratic')
         # With a boxsize larger than the cutout we expect the fitting to
         # fail for all stars, due to star._fit_error_status
-        with pytest.raises(ValueError), pytest.warns(AstropyUserWarning):
+        match1 = 'The ePSF fitting failed for all stars'
+        match2 = r'The star at .* cannot be fit because its fitting region '
+        with (pytest.raises(ValueError, match=match1),
+                pytest.warns(AstropyUserWarning, match=match2)):
             epsf_builder(stars)
 
     def test_epsf_build_invalid_fitter(self):
         """
         Test that the input fitter is an EPSFFitter instance.
         """
-        with pytest.raises(TypeError):
+        match = 'fitter must be an EPSFFitter instance'
+        with pytest.raises(TypeError, match=match):
             EPSFBuilder(fitter=EPSFFitter, maxiters=3)
 
-        with pytest.raises(TypeError):
-            EPSFBuilder(fitter=LevMarLSQFitter(), maxiters=3)
+        with pytest.raises(TypeError, match=match):
+            EPSFBuilder(fitter=TRFLSQFitter(), maxiters=3)
 
-        with pytest.raises(TypeError):
-            EPSFBuilder(fitter=LevMarLSQFitter, maxiters=3)
+        with pytest.raises(TypeError, match=match):
+            EPSFBuilder(fitter=TRFLSQFitter, maxiters=3)
 
 
 def test_epsfbuilder_inputs():
     # invalid inputs
-    with pytest.raises(ValueError):
+    match = "'oversampling' must be specified"
+    with pytest.raises(ValueError, match=match):
         EPSFBuilder(oversampling=None)
-    with pytest.raises(ValueError):
+    match = 'oversampling must be > 0'
+    with pytest.raises(ValueError, match=match):
         EPSFBuilder(oversampling=-1)
-    with pytest.raises(ValueError):
+    match = "'maxiters' must be a positive number"
+    with pytest.raises(ValueError, match=match):
         EPSFBuilder(maxiters=-1)
-    with pytest.raises(ValueError):
+    match = 'oversampling must be > 0'
+    with pytest.raises(ValueError, match=match):
         EPSFBuilder(oversampling=[-1, 4])
 
     # valid inputs
@@ -152,39 +196,14 @@ def test_epsfbuilder_inputs():
 
     # invalid inputs
     for sigma_clip in [None, [], 'a']:
-        with pytest.raises(ValueError):
+        match = 'sigma_clip must be an astropy.stats.SigmaClip instance'
+        with pytest.raises(TypeError, match=match):
             EPSFBuilder(sigma_clip=sigma_clip)
 
     # valid inputs
     EPSFBuilder(sigma_clip=SigmaClip(sigma=2.5, cenfunc='mean', maxiters=2))
 
 
-def test_epsfmodel_inputs():
-    data = np.array([[], []])
-    with pytest.raises(ValueError):
-        EPSFModel(data)
-
-    data = np.ones((5, 5), dtype=float)
-    data[2, 2] = np.inf
-    with pytest.raises(ValueError, match='must be finite'):
-        EPSFModel(data)
-
-    data[2, 2] = np.nan
-    with pytest.raises(ValueError, match='must be finite'):
-        EPSFModel(data, flux=None)
-
-    data[2, 2] = 1
-    for oversampling in [-1, [-2, 4], (1, 4, 8), ((1, 2), (3, 4)),
-                         np.ones((2, 2, 2)), 2.1, np.nan, (1, np.inf)]:
-        with pytest.raises(ValueError):
-            EPSFModel(data, oversampling=oversampling)
-
-    origin = (1, 2, 3)
-    with pytest.raises(TypeError):
-        EPSFModel(data, origin=origin)
-
-
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 @pytest.mark.parametrize('oversamp', [3, 4])
 def test_epsf_build_oversampling(oversamp):
     offsets = (np.arange(oversamp) * 1.0 / oversamp - 0.5 + 1.0
@@ -194,7 +213,7 @@ def test_epsf_build_oversampling(oversamp):
     ydithers = np.transpose(xydithers)[1]
 
     nstars = oversamp**2
-    sigma = 3.0
+    fwhm = 7.0
     sources = Table()
     offset = 50
     size = oversamp * offset + offset
@@ -202,9 +221,9 @@ def test_epsf_build_oversampling(oversamp):
     sources['amplitude'] = np.full((nstars,), 100.0)
     sources['x_0'] = x.ravel() + xdithers
     sources['y_0'] = y.ravel() + ydithers
-    sources['sigma'] = np.full((nstars,), sigma)
+    sources['fwhm'] = np.full((nstars,), fwhm)
 
-    psf_model = IntegratedGaussianPRF(sigma=sigma)
+    psf_model = CircularGaussianPRF(fwhm=fwhm)
     shape = (size, size)
     data = make_model_image(shape, psf_model, sources)
     nddata = NDData(data=data)
@@ -219,8 +238,8 @@ def test_epsf_build_oversampling(oversamp):
     # input PSF shape
     size = epsf.data.shape[0]
     cen = (size - 1) / 2
-    sigma2 = oversamp * sigma
-    m = IntegratedGaussianPRF(sigma2, x_0=cen, y_0=cen, flux=1)
+    fwhm2 = oversamp * fwhm
+    m = CircularGaussianPRF(flux=1, x_0=cen, y_0=cen, fwhm=fwhm2)
     yy, xx = np.mgrid[0:size, 0:size]
     psf = m(xx, yy)
 
