@@ -6,8 +6,9 @@ Tests for the photometry module.
 import astropy.units as u
 import numpy as np
 import pytest
-from astropy.modeling.fitting import LMLSQFitter, SimplexLSQFitter
-from astropy.modeling.models import Gaussian1D, Gaussian2D, custom_model
+from astropy.modeling.fitting import (LMLSQFitter, SimplexLSQFitter,
+                                      TRFLSQFitter)
+from astropy.modeling.models import Gaussian1D, Gaussian2D
 from astropy.nddata import NDData, StdDevUncertainty
 from astropy.table import QTable, Table
 from astropy.utils.exceptions import AstropyUserWarning
@@ -16,16 +17,15 @@ from numpy.testing import assert_allclose, assert_equal
 from photutils.background import LocalBackground, MMMBackground
 from photutils.datasets import make_model_image, make_noise_image
 from photutils.detection import DAOStarFinder
-from photutils.psf import (IntegratedGaussianPRF, IterativePSFPhotometry,
+from photutils.psf import (CircularGaussianPRF, IterativePSFPhotometry,
                            PSFPhotometry, SourceGrouper, make_psf_model,
                            make_psf_model_image)
-from photutils.utils._optional_deps import HAS_SCIPY
 from photutils.utils.exceptions import NoDetectionsWarning
 
 
 @pytest.fixture(name='test_data')
 def fixture_test_data():
-    psf_model = IntegratedGaussianPRF(flux=1, sigma=2.7 / 2.35)
+    psf_model = CircularGaussianPRF(flux=1, fwhm=2.7)
     model_shape = (9, 9)
     n_sources = 10
     shape = (101, 101)
@@ -40,33 +40,26 @@ def fixture_test_data():
     return data, error, true_params
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_invalid_inputs():
-    model = IntegratedGaussianPRF(sigma=1.0)
+    model = CircularGaussianPRF(fwhm=1.0)
 
     match = 'psf_model must be an Astropy Model subclass'
     with pytest.raises(TypeError, match=match):
         _ = PSFPhotometry(1, 3)
 
     match = 'psf_model must be two-dimensional'
+    psf_model = Gaussian1D()
     with pytest.raises(ValueError, match=match):
-        psf_model = Gaussian1D()
         _ = PSFPhotometry(psf_model, 3)
 
-    @custom_model
-    def my_model(x, y, flux=1, x_0=0, y_0=0, sigma=1):
-        return flux, flux * 2
-    m = my_model()
-    m.n_outputs = 2
-    psf_model = my_model()
     match = 'psf_model must be two-dimensional'
+    psf_model = Gaussian1D()
     with pytest.raises(ValueError, match=match):
-        psf_model = Gaussian1D()
         _ = PSFPhotometry(psf_model, 3)
 
     match = 'Invalid PSF model - could not find PSF parameter names'
+    psf_model = Gaussian2D()
     with pytest.raises(ValueError, match=match):
-        psf_model = Gaussian2D()
         _ = PSFPhotometry(psf_model, 3)
 
     match = 'fit_shape must have an odd value for both axes'
@@ -74,7 +67,7 @@ def test_invalid_inputs():
         with pytest.raises(ValueError, match=match):
             _ = PSFPhotometry(model, shape)
 
-    match = 'fit_shape must be > 0'
+    match = 'fit_shape must be >= 1'
     with pytest.raises(ValueError, match=match):
         _ = PSFPhotometry(model, (-1, 1))
 
@@ -90,8 +83,8 @@ def test_invalid_inputs():
             _ = PSFPhotometry(model, 1, **{key: val})
 
     match = 'localbkg_estimator must be a LocalBackground instance'
+    localbkg = MMMBackground()
     with pytest.raises(ValueError, match=match):
-        localbkg = MMMBackground()
         _ = PSFPhotometry(model, 1, localbkg_estimator=localbkg)
 
     match = 'aperture_radius must be a strictly-positive scalar'
@@ -109,35 +102,35 @@ def test_invalid_inputs():
         _ = psfphot(np.arange(3))
 
     match = 'data and error must have the same shape.'
+    data = np.ones((11, 11))
+    error = np.ones((3, 3))
     with pytest.raises(ValueError, match=match):
-        data = np.ones((11, 11))
-        error = np.ones((3, 3))
         _ = psfphot(data, error=error)
 
     match = 'data and mask must have the same shape.'
+    data = np.ones((11, 11))
+    mask = np.ones((3, 3))
     with pytest.raises(ValueError, match=match):
-        data = np.ones((11, 11))
-        mask = np.ones((3, 3))
         _ = psfphot(data, mask=mask)
 
     match = 'init_params must be an astropy Table'
+    data = np.ones((11, 11))
     with pytest.raises(TypeError, match=match):
-        data = np.ones((11, 11))
         _ = psfphot(data, init_params=1)
 
     match = ('init_param must contain valid column names for the x and y '
              'source positions')
+    tbl = Table()
+    tbl['a'] = np.arange(3)
+    data = np.ones((11, 11))
     with pytest.raises(ValueError, match=match):
-        tbl = Table()
-        tbl['a'] = np.arange(3)
-        data = np.ones((11, 11))
         _ = psfphot(data, init_params=tbl)
 
     # test no finder or init_params
     match = 'finder must be defined if init_params is not input'
     psfphot = PSFPhotometry(model, (3, 3), aperture_radius=5)
+    data = np.ones((11, 11))
     with pytest.raises(ValueError, match=match):
-        data = np.ones((11, 11))
         _ = psfphot(data)
 
     # data has unmasked non-finite value
@@ -146,44 +139,44 @@ def test_invalid_inputs():
     init_params = Table()
     init_params['x_init'] = [1, 2]
     init_params['y_init'] = [1, 2]
+    data = np.ones((11, 11))
+    data[5, 5] = np.nan
     with pytest.warns(AstropyUserWarning, match=match):
-        data = np.ones((11, 11))
-        data[5, 5] = np.nan
         _ = psfphot2(data, init_params=init_params)
 
     # mask is input, but data has unmasked non-finite value
     match = 'Input data contains unmasked non-finite values'
+    data = np.ones((11, 11))
+    data[5, 5] = np.nan
+    mask = np.zeros(data.shape, dtype=bool)
+    mask[7, 7] = True
     with pytest.warns(AstropyUserWarning, match=match):
-        data = np.ones((11, 11))
-        data[5, 5] = np.nan
-        mask = np.zeros(data.shape, dtype=bool)
-        mask[7, 7] = True
         _ = psfphot2(data, mask=mask, init_params=init_params)
 
     match = 'init_params local_bkg column contains non-finite values'
+    tbl = Table()
+    init_params['x_init'] = [1, 2]
+    init_params['y_init'] = [1, 2]
+    init_params['local_bkg'] = [0.1, np.inf]
+    data = np.ones((11, 11))
     with pytest.raises(ValueError, match=match):
-        tbl = Table()
-        init_params['x_init'] = [1, 2]
-        init_params['y_init'] = [1, 2]
-        init_params['local_bkg'] = [0.1, np.inf]
-        data = np.ones((11, 11))
         _ = psfphot(data, init_params=init_params)
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_psf_photometry(test_data):
     data, error, sources = test_data
 
-    psf_model = IntegratedGaussianPRF(flux=1, sigma=2.7 / 2.35)
+    psf_model = CircularGaussianPRF(flux=1, fwhm=2.7)
     fit_shape = (5, 5)
     finder = DAOStarFinder(6.0, 2.0)
     psfphot = PSFPhotometry(psf_model, fit_shape, finder=finder,
                             aperture_radius=4)
     phot = psfphot(data, error=error)
-    resid_data = psfphot.make_residual_image(data, fit_shape)
+    resid_data = psfphot.make_residual_image(data, psf_shape=fit_shape)
 
     assert isinstance(psfphot.finder_results, QTable)
     assert isinstance(phot, QTable)
+    assert isinstance(psfphot.results, QTable)
     assert len(phot) == len(sources)
     assert isinstance(resid_data, np.ndarray)
     assert resid_data.shape == data.shape
@@ -195,11 +188,11 @@ def test_psf_photometry(test_data):
 
     keys = ('fit_infos', 'fit_error_indices')
     for key in keys:
-        assert key in psfphot.fit_results
+        assert key in psfphot.fit_info
 
     # test that repeated calls reset the results
     phot = psfphot(data, error=error)
-    assert len(psfphot.fit_results['fit_infos']) == len(phot)
+    assert len(psfphot.fit_info['fit_infos']) == len(phot)
 
     # test units
     unit = u.Jy
@@ -210,29 +203,29 @@ def test_psf_photometry(test_data):
     colnames = ('flux_init', 'flux_fit', 'flux_err', 'local_bkg')
     for col in colnames:
         assert photu[col].unit == unit
-    resid_datau = psfphotu.make_residual_image(data << unit, fit_shape)
+    resid_datau = psfphotu.make_residual_image(data << unit,
+                                               psf_shape=fit_shape)
     assert resid_datau.unit == unit
     colnames = ('qfit', 'cfit')
     for col in colnames:
         assert not isinstance(col, u.Quantity)
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
-@pytest.mark.parametrize('fit_sigma', (False, True))
-def test_psf_photometry_forced(test_data, fit_sigma):
+@pytest.mark.parametrize('fit_fwhm', [False, True])
+def test_psf_photometry_forced(test_data, fit_fwhm):
     data, error, sources = test_data
 
-    psf_model = IntegratedGaussianPRF(flux=1, sigma=2.7 / 2.35)
+    psf_model = CircularGaussianPRF(flux=1, fwhm=2.7)
     psf_model.x_0.fixed = True
     psf_model.y_0.fixed = True
-    if fit_sigma:
-        psf_model.sigma.fixed = False
+    if fit_fwhm:
+        psf_model.fwhm.fixed = False
     fit_shape = (5, 5)
     finder = DAOStarFinder(6.0, 2.0)
     psfphot = PSFPhotometry(psf_model, fit_shape, finder=finder,
                             aperture_radius=4)
     phot = psfphot(data, error=error)
-    resid_data = psfphot.make_residual_image(data, fit_shape)
+    resid_data = psfphot.make_residual_image(data, psf_shape=fit_shape)
 
     assert isinstance(psfphot.finder_results, QTable)
     assert isinstance(phot, QTable)
@@ -242,19 +235,18 @@ def test_psf_photometry_forced(test_data, fit_sigma):
     assert phot.colnames[:4] == ['id', 'group_id', 'group_size', 'local_bkg']
     assert_equal(phot['x_init'], phot['x_fit'])
 
-    if fit_sigma:
-        col = 'sigma'
+    if fit_fwhm:
+        col = 'fwhm'
         suffixes = ('_init', '_fit', '_err')
         colnames = [col + suffix for suffix in suffixes]
         for colname in colnames:
             assert colname in phot.colnames
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_psf_photometry_nddata(test_data):
-    data, error, sources = test_data
+    data, error, _ = test_data
 
-    psf_model = IntegratedGaussianPRF(flux=1, sigma=2.7 / 2.35)
+    psf_model = CircularGaussianPRF(flux=1, fwhm=2.7)
     fit_shape = (5, 5)
     finder = DAOStarFinder(6.0, 2.0)
 
@@ -265,8 +257,8 @@ def test_psf_photometry_nddata(test_data):
                             aperture_radius=4)
     phot1 = psfphot(data, error=error)
     phot2 = psfphot(nddata)
-    resid_data1 = psfphot.make_residual_image(data, fit_shape)
-    resid_data2 = psfphot.make_residual_image(nddata, fit_shape)
+    resid_data1 = psfphot.make_residual_image(data, psf_shape=fit_shape)
+    resid_data2 = psfphot.make_residual_image(nddata, psf_shape=fit_shape)
 
     assert np.all(phot1 == phot2)
     assert isinstance(resid_data2, NDData)
@@ -285,16 +277,15 @@ def test_psf_photometry_nddata(test_data):
     assert photu['flux_init'].unit == unit
     assert photu['flux_fit'].unit == unit
     assert photu['flux_err'].unit == unit
-    resid_data3 = psfphotu.make_residual_image(nddata, fit_shape)
+    resid_data3 = psfphotu.make_residual_image(nddata, psf_shape=fit_shape)
     assert resid_data3.unit == unit
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_model_residual_image(test_data):
     data, error, _ = test_data
 
     data = data + 10
-    psf_model = IntegratedGaussianPRF(flux=1, sigma=2.7 / 2.35)
+    psf_model = CircularGaussianPRF(flux=1, fwhm=2.7)
     fit_shape = (5, 5)
     finder = DAOStarFinder(16.0, 2.0)
     bkgstat = MMMBackground()
@@ -305,13 +296,13 @@ def test_model_residual_image(test_data):
     psfphot(data, error=error)
 
     psf_shape = (25, 25)
-    model1 = psfphot.make_model_image(data.shape, psf_shape,
+    model1 = psfphot.make_model_image(data.shape, psf_shape=psf_shape,
                                       include_localbkg=False)
-    model2 = psfphot.make_model_image(data.shape, psf_shape,
+    model2 = psfphot.make_model_image(data.shape, psf_shape=psf_shape,
                                       include_localbkg=True)
-    resid1 = psfphot.make_residual_image(data, psf_shape,
+    resid1 = psfphot.make_residual_image(data, psf_shape=psf_shape,
                                          include_localbkg=False)
-    resid2 = psfphot.make_residual_image(data, psf_shape,
+    resid2 = psfphot.make_residual_image(data, psf_shape=psf_shape,
                                          include_localbkg=True)
 
     x, y = 0, 100
@@ -327,14 +318,13 @@ def test_model_residual_image(test_data):
     assert resid2[y, x] < -9
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
-@pytest.mark.parametrize('fit_stddev', (False, True))
+@pytest.mark.parametrize('fit_stddev', [False, True])
 def test_psf_photometry_compound_psfmodel(test_data, fit_stddev):
     """
     Test compound models output from ``make_psf_model``.
     """
     data, error, sources = test_data
-    x_stddev = y_stddev = 1.7
+    x_stddev = y_stddev = 1.2
     psf_func = Gaussian2D(amplitude=1, x_mean=0, y_mean=0, x_stddev=x_stddev,
                           y_stddev=y_stddev)
     psf_model = make_psf_model(psf_func, x_name='x_mean', y_name='y_mean')
@@ -360,13 +350,13 @@ def test_psf_photometry_compound_psfmodel(test_data, fit_stddev):
 
     # test model and residual images
     psf_shape = (9, 9)
-    model1 = psfphot.make_model_image(data.shape, psf_shape,
+    model1 = psfphot.make_model_image(data.shape, psf_shape=psf_shape,
                                       include_localbkg=False)
-    resid1 = psfphot.make_residual_image(data, psf_shape,
+    resid1 = psfphot.make_residual_image(data, psf_shape=psf_shape,
                                          include_localbkg=False)
-    model2 = psfphot.make_model_image(data.shape, psf_shape,
+    model2 = psfphot.make_model_image(data.shape, psf_shape=psf_shape,
                                       include_localbkg=True)
-    resid2 = psfphot.make_residual_image(data, psf_shape,
+    resid2 = psfphot.make_residual_image(data, psf_shape=psf_shape,
                                          include_localbkg=True)
     assert model1.shape == data.shape
     assert model2.shape == data.shape
@@ -388,20 +378,15 @@ def test_psf_photometry_compound_psfmodel(test_data, fit_stddev):
         for colname in colnames:
             assert colname in phot.colnames
 
-    # test results when fit does not converge (fitter_maxiters=10)
+    # test results when fit does not converge (fitter_maxiters=3)
     match = r'One or more fit\(s\) may not have converged.'
     with pytest.warns(AstropyUserWarning, match=match):
         psfphot = PSFPhotometry(psf_model, fit_shape, finder=finder,
-                                aperture_radius=4, fitter_maxiters=10)
+                                aperture_radius=4, fitter_maxiters=3)
         phot = psfphot(data, error=error)
-        columns1 = ['x_err', 'y_err', 'flux_err']
-        if fit_stddev:
-            columns1 += ['x_stddev_2_err', 'y_stddev_2_err']
-        for column in columns1:
-            assert np.all(np.isnan(phot[column]))
+        assert len(phot) == len(sources)
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 @pytest.mark.parametrize('mode', ['new', 'all'])
 def test_iterative_psf_photometry_compound(mode):
     x_stddev = y_stddev = 1.7
@@ -430,8 +415,10 @@ def test_iterative_psf_photometry_compound(mode):
     fit_shape = (5, 5)
     finder = DAOStarFinder(6.0, 3.0)
     grouper = SourceGrouper(min_separation=2)
+
     psfphot = IterativePSFPhotometry(psf_model, fit_shape, finder=finder,
                                      grouper=grouper, aperture_radius=4,
+                                     sub_shape=fit_shape,
                                      mode=mode, maxiters=2)
     phot = psfphot(data, error=error, init_params=init_params)
     assert isinstance(phot, QTable)
@@ -445,13 +432,13 @@ def test_iterative_psf_photometry_compound(mode):
 
     # test model and residual images
     psf_shape = (9, 9)
-    model1 = psfphot.make_model_image(data.shape, psf_shape,
+    model1 = psfphot.make_model_image(data.shape, psf_shape=psf_shape,
                                       include_localbkg=False)
-    resid1 = psfphot.make_residual_image(data, psf_shape,
+    resid1 = psfphot.make_residual_image(data, psf_shape=psf_shape,
                                          include_localbkg=False)
-    model2 = psfphot.make_model_image(data.shape, psf_shape,
+    model2 = psfphot.make_model_image(data.shape, psf_shape=psf_shape,
                                       include_localbkg=True)
-    resid2 = psfphot.make_residual_image(data, psf_shape,
+    resid2 = psfphot.make_residual_image(data, psf_shape=psf_shape,
                                          include_localbkg=True)
     assert model1.shape == data.shape
     assert model2.shape == data.shape
@@ -473,11 +460,10 @@ def test_iterative_psf_photometry_compound(mode):
         assert colname in phot.colnames
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_psf_photometry_mask(test_data):
     data, error, sources = test_data
 
-    psf_model = IntegratedGaussianPRF(flux=1, sigma=2.7 / 2.35)
+    psf_model = CircularGaussianPRF(flux=1, fwhm=2.7)
     fit_shape = (5, 5)
     finder = DAOStarFinder(6.0, 2.0)
     psfphot = PSFPhotometry(psf_model, fit_shape, finder=finder,
@@ -511,34 +497,21 @@ def test_psf_photometry_mask(test_data):
         assert len(phot) == len(sources)
 
     # mask all True; finder returns no sources
-    with pytest.warns(NoDetectionsWarning):
+    match = 'No sources were found'
+    with pytest.warns(NoDetectionsWarning, match=match):
         mask = np.ones(data.shape, dtype=bool)
         psfphot(data, mask=mask)
 
     # completely masked source
     match = ('is completely masked. Remove the source from init_params '
              'or correct the input mask')
+    init_params = QTable()
+    init_params['x'] = [63]
+    init_params['y'] = [49]
+    mask = np.ones(data.shape, dtype=bool)
     with pytest.raises(ValueError, match=match):
-        init_params = QTable()
-        init_params['x'] = [63]
-        init_params['y'] = [49]
-        mask = np.ones(data.shape, dtype=bool)
         _ = psfphot(data, mask=mask, init_params=init_params)
 
-    # completely masked source
-    match = ('the number of data points available to fit is less than the '
-             'number of fit parameters')
-    with pytest.raises(ValueError, match=match):
-        init_params = QTable()
-        init_params['x'] = [63]
-        init_params['y'] = [49]
-        mask = np.zeros(data.shape, dtype=bool)
-        mask[48:50, :] = True
-        mask[50, 63:65] = True
-        psfphot = PSFPhotometry(psf_model, (3, 3), finder=finder,
-                                aperture_radius=4)
-        _ = psfphot(data_orig, mask=mask, init_params=init_params)
-
     # masked central pixel
     init_params = QTable()
     init_params['x'] = [63]
@@ -562,12 +535,11 @@ def test_psf_photometry_mask(test_data):
     psfphot(data, mask=mask, init_params=init_params)
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_psf_photometry_init_params(test_data):
     data, error, _ = test_data
     data = data.copy()
 
-    psf_model = IntegratedGaussianPRF(flux=1, sigma=2.7 / 2.35)
+    psf_model = CircularGaussianPRF(flux=1, fwhm=2.7)
     fit_shape = (5, 5)
     finder = DAOStarFinder(6.0, 2.0)
     psfphot = PSFPhotometry(psf_model, fit_shape, finder=finder,
@@ -581,9 +553,9 @@ def test_psf_photometry_init_params(test_data):
     assert len(phot) == 1
 
     match = 'aperture_radius must be defined if init_params is not input'
+    psfphot = PSFPhotometry(psf_model, fit_shape, finder=finder,
+                            aperture_radius=None)
     with pytest.raises(ValueError, match=match):
-        psfphot = PSFPhotometry(psf_model, fit_shape, finder=finder,
-                                aperture_radius=None)
         _ = psfphot(data, error=error, init_params=init_params)
 
     psfphot = PSFPhotometry(psf_model, fit_shape, finder=finder,
@@ -642,7 +614,6 @@ def test_psf_photometry_init_params(test_data):
     assert phot['flux_init'][0] == flux
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_psf_photometry_init_params_units(test_data):
     data, error, _ = test_data
     data2 = data.copy()
@@ -652,7 +623,7 @@ def test_psf_photometry_init_params_units(test_data):
     data2 <<= unit
     error2 <<= unit
 
-    psf_model = IntegratedGaussianPRF(flux=1, sigma=2.7 / 2.35)
+    psf_model = CircularGaussianPRF(flux=1, fwhm=2.7)
     fit_shape = (5, 5)
     psfphot = PSFPhotometry(psf_model, fit_shape, finder=None,
                             aperture_radius=4)
@@ -667,11 +638,11 @@ def test_psf_photometry_init_params_units(test_data):
     assert len(phot) == 1
 
     for val in (True, False):
-        im = psfphot.make_model_image(data2.shape, fit_shape,
+        im = psfphot.make_model_image(data2.shape, psf_shape=fit_shape,
                                       include_localbkg=val)
         assert isinstance(im, u.Quantity)
         assert im.unit == unit
-        resid = psfphot.make_residual_image(data2, fit_shape,
+        resid = psfphot.make_residual_image(data2, psf_shape=fit_shape,
                                             include_localbkg=val)
         assert isinstance(resid, u.Quantity)
         assert resid.unit == unit
@@ -698,12 +669,11 @@ def test_psf_photometry_init_params_units(test_data):
             _ = psfphot(data << u.Jy, init_params=init_params2)
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_psf_photometry_init_params_columns(test_data):
     data, error, _ = test_data
     data = data.copy()
 
-    psf_model = IntegratedGaussianPRF(flux=1, sigma=2.7 / 2.35)
+    psf_model = CircularGaussianPRF(flux=1, fwhm=2.7)
     fit_shape = (5, 5)
     finder = DAOStarFinder(6.0, 2.0)
     psfphot = PSFPhotometry(psf_model, fit_shape, finder=finder)
@@ -712,13 +682,14 @@ def test_psf_photometry_init_params_columns(test_data):
                    'cen', '_cen', 'pos', '_pos', '_0', '0')
     flux_cols = ['flux_init', 'flux_0', 'flux0', 'flux', 'source_sum',
                  'segment_flux', 'kron_flux']
-    flux_cols += flux_cols[0:4]  # pad to have same length as xy_suffixes
+    pad = len(xy_suffixes) - len(flux_cols)
+    flux_cols += flux_cols[0:pad]  # pad to have same length as xy_suffixes
 
     xcols = ['x' + i for i in xy_suffixes]
     ycols = ['y' + i for i in xy_suffixes]
 
     phots = []
-    for xcol, ycol, fluxcol in zip(xcols, ycols, flux_cols):
+    for xcol, ycol, fluxcol in zip(xcols, ycols, flux_cols, strict=True):
         init_params = QTable()
         init_params[xcol] = [42]
         init_params[ycol] = [36]
@@ -734,11 +705,10 @@ def test_psf_photometry_init_params_columns(test_data):
         assert_allclose(phot['flux_fit'], phots[0]['flux_fit'])
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_grouper(test_data):
     data, error, sources = test_data
 
-    psf_model = IntegratedGaussianPRF(flux=1, sigma=2.7 / 2.35)
+    psf_model = CircularGaussianPRF(flux=1, fwhm=2.7)
     fit_shape = (5, 5)
     finder = DAOStarFinder(6.0, 2.0)
     grouper = SourceGrouper(min_separation=20)
@@ -751,9 +721,8 @@ def test_grouper(test_data):
     assert_equal(phot['group_size'], (1, 1, 1, 1, 3, 3, 3, 2, 2, 1))
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_large_group_warning():
-    psf_model = IntegratedGaussianPRF(flux=1, sigma=1.0)
+    psf_model = CircularGaussianPRF(flux=1, fwhm=2)
     grouper = SourceGrouper(min_separation=50)
     model_shape = (5, 5)
     fit_shape = (5, 5)
@@ -769,11 +738,10 @@ def test_large_group_warning():
         psfphot(data, init_params=true_params)
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_local_bkg(test_data):
     data, error, sources = test_data
 
-    psf_model = IntegratedGaussianPRF(flux=1, sigma=2.7 / 2.35)
+    psf_model = CircularGaussianPRF(flux=1, fwhm=2.7)
     fit_shape = (5, 5)
     finder = DAOStarFinder(6.0, 2.0)
     grouper = SourceGrouper(min_separation=20)
@@ -788,11 +756,10 @@ def test_local_bkg(test_data):
     assert np.count_nonzero(phot['local_bkg']) == len(sources)
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_fixed_params(test_data):
     data, error, _ = test_data
 
-    psf_model = IntegratedGaussianPRF(flux=1, sigma=2.7 / 2.35)
+    psf_model = CircularGaussianPRF(flux=1, fwhm=2.7)
     psf_model.x_0.fixed = True
     psf_model.y_0.fixed = True
     psf_model.flux.fixed = True
@@ -801,20 +768,17 @@ def test_fixed_params(test_data):
     psfphot = PSFPhotometry(psf_model, fit_shape, finder=finder,
                             aperture_radius=4)
 
-    match = r'One or more fit\(s\) may not have converged.'
-    with pytest.warns(AstropyUserWarning, match=match):
-        phot = psfphot(data, error=error)
-        assert np.all(np.isnan(phot['x_err']))
-        assert np.all(np.isnan(phot['y_err']))
-        assert np.all(np.isnan(phot['flux_err']))
+    match = r'`bounds` must contain 2 elements'
+    with pytest.raises(ValueError, match=match):
+        psfphot(data, error=error)
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_fit_warning(test_data):
     data, _, _ = test_data
 
-    psf_model = IntegratedGaussianPRF(flux=1, sigma=2.7 / 2.35)
+    psf_model = CircularGaussianPRF(flux=1, fwhm=2.7)
     psf_model.flux.fixed = False
+    psf_model.fwhm.bounds = (None, None)
     fit_shape = (5, 5)
     fitter = LMLSQFitter()  # uses "status" instead of "ierr"
     finder = DAOStarFinder(6.0, 2.0)
@@ -826,10 +790,9 @@ def test_fit_warning(test_data):
     match = r'One or more fit\(s\) may not have converged.'
     with pytest.warns(AstropyUserWarning, match=match):
         _ = psfphot(data)
-        assert len(psfphot.fit_results['fit_error_indices']) > 0
+        assert len(psfphot.fit_info['fit_error_indices']) > 0
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_fitter_no_maxiters_no_metrics(test_data):
     """
     Test with a fitter that does not have a maxiters parameter and does
@@ -837,7 +800,7 @@ def test_fitter_no_maxiters_no_metrics(test_data):
     """
     data, error, _ = test_data
 
-    psf_model = IntegratedGaussianPRF(flux=1, sigma=2.7 / 2.35)
+    psf_model = CircularGaussianPRF(flux=1, fwhm=2.7)
     psf_model.flux.fixed = False
     fit_shape = (5, 5)
     fitter = SimplexLSQFitter()  # does not produce residual array
@@ -851,11 +814,69 @@ def test_fitter_no_maxiters_no_metrics(test_data):
         assert np.all(np.isnan(phot['cfit']))
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
+def test_xy_bounds(test_data):
+    data, error, _ = test_data
+
+    psf_model = CircularGaussianPRF(flux=1, fwhm=2.7)
+    fit_shape = (5, 5)
+    init_params = QTable()
+    init_params['x'] = [65]
+    init_params['y'] = [51]
+    xy_bounds = (1, 1)
+    psfphot = PSFPhotometry(psf_model, fit_shape, finder=None,
+                            aperture_radius=4, xy_bounds=xy_bounds)
+    phot = psfphot(data, error=error, init_params=init_params)
+    assert len(phot) == len(init_params)
+    assert_allclose(phot['x_fit'], 64.0)  # at lower bound
+    assert_allclose(phot['y_fit'], 50.0)  # at lower bound
+
+    psfphot2 = PSFPhotometry(psf_model, fit_shape, finder=None,
+                             aperture_radius=4, xy_bounds=1)
+    phot2 = psfphot2(data, error=error, init_params=init_params)
+    cols = ('x_fit', 'y_fit', 'flux_fit')
+    for col in cols:
+        assert np.all(phot[col] == phot2[col])
+
+    xy_bounds = (None, 1)
+    psfphot = PSFPhotometry(psf_model, fit_shape, finder=None,
+                            aperture_radius=4, xy_bounds=xy_bounds)
+    phot = psfphot(data, error=error, init_params=init_params)
+    assert phot['x_fit'] < 64.0
+    assert_allclose(phot['y_fit'], 50.0)  # at lower bound
+
+    xy_bounds = (1, None)
+    psfphot = PSFPhotometry(psf_model, fit_shape, finder=None,
+                            aperture_radius=4, xy_bounds=xy_bounds)
+    phot = psfphot(data, error=error, init_params=init_params)
+    assert_allclose(phot['x_fit'], 64.0)  # at lower bound
+    assert phot['y_fit'] < 50.0
+
+    xy_bounds = (None, None)
+    psfphot = PSFPhotometry(psf_model, fit_shape, finder=None,
+                            aperture_radius=4, xy_bounds=xy_bounds)
+    init_params['x'] = [63]
+    init_params['y'] = [49]
+    phot = psfphot(data, error=error, init_params=init_params)
+    assert phot['x_fit'] < 63.3
+    assert phot['y_fit'] < 48.7
+    assert phot['flags'] == 0
+
+    # test invalid inputs
+    match = 'xy_bounds must have 1 or 2 elements'
+    with pytest.raises(ValueError, match=match):
+        PSFPhotometry(psf_model, fit_shape, xy_bounds=(1, 2, 3))
+    match = 'xy_bounds must be a 1D array'
+    with pytest.raises(ValueError, match=match):
+        PSFPhotometry(psf_model, fit_shape, xy_bounds=np.ones((1, 1)))
+    match = 'xy_bounds must be strictly positive'
+    with pytest.raises(ValueError, match=match):
+        PSFPhotometry(psf_model, fit_shape, xy_bounds=(-1, 2))
+
+
 def test_iterative_psf_photometry_mode_new(test_data):
     data, error, sources = test_data
 
-    psf_model = IntegratedGaussianPRF(flux=1, sigma=2.7 / 2.35)
+    psf_model = CircularGaussianPRF(flux=1, fwhm=2.7)
     fit_shape = (5, 5)
     bkgstat = MMMBackground()
     localbkg_estimator = LocalBackground(5, 10, bkgstat)
@@ -876,12 +897,12 @@ def test_iterative_psf_photometry_mode_new(test_data):
     assert 'iter_detected' in phot.colnames
     assert len(phot) == len(sources)
 
-    resid_data = psfphot.make_residual_image(data, fit_shape)
+    resid_data = psfphot.make_residual_image(data, psf_shape=fit_shape)
     assert isinstance(resid_data, np.ndarray)
     assert resid_data.shape == data.shape
 
     nddata = NDData(data)
-    resid_nddata = psfphot.make_residual_image(nddata, fit_shape)
+    resid_nddata = psfphot.make_residual_image(nddata, psf_shape=fit_shape)
     assert isinstance(resid_nddata, NDData)
     assert resid_nddata.data.shape == data.shape
 
@@ -896,7 +917,7 @@ def test_iterative_psf_photometry_mode_new(test_data):
     colnames = ('flux_init', 'flux_fit', 'flux_err', 'local_bkg')
     for col in colnames:
         assert_allclose(phot0[col], phot[col])
-    resid_nddata = psfphot.make_residual_image(nddata, fit_shape)
+    resid_nddata = psfphot.make_residual_image(nddata, psf_shape=fit_shape)
     assert isinstance(resid_nddata, NDData)
     assert_equal(resid_nddata.data, resid_data)
 
@@ -923,7 +944,7 @@ def test_iterative_psf_photometry_mode_new(test_data):
     for col in colnames:
         assert phot3[col].unit == unit
         assert_allclose(phot3[col].value, phot2[col].value)
-    resid_nddata = psfphot.make_residual_image(nddata, fit_shape)
+    resid_nddata = psfphot.make_residual_image(nddata, psf_shape=fit_shape)
     assert isinstance(resid_nddata, NDData)
     assert resid_nddata.unit == unit
 
@@ -933,12 +954,12 @@ def test_iterative_psf_photometry_mode_new(test_data):
                                      mode='new',
                                      localbkg_estimator=localbkg_estimator,
                                      aperture_radius=4)
-    with pytest.warns(NoDetectionsWarning):
+    match = 'No sources were found'
+    with pytest.warns(NoDetectionsWarning, match=match):
         phot = psfphot(data, error=error)
         assert phot is None
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_iterative_psf_photometry_mode_all():
     sources = QTable()
     sources['x_0'] = [50, 45, 55, 27, 22, 77, 82]
@@ -946,7 +967,7 @@ def test_iterative_psf_photometry_mode_all():
     sources['flux'] = [1000, 100, 50, 1000, 100, 1000, 100]
 
     shape = (101, 101)
-    psf_model = IntegratedGaussianPRF(flux=500, sigma=4.0)
+    psf_model = CircularGaussianPRF(flux=500, fwhm=9.4)
     psf_shape = (41, 41)
     data = make_model_image(shape, psf_model, sources, model_shape=psf_shape)
 
@@ -967,7 +988,7 @@ def test_iterative_psf_photometry_mode_all():
     assert_equal(phot['iter_detected'], [1, 1, 1, 2, 2, 2, 2])
     assert_allclose(phot['flux_fit'], [1000, 1000, 1000, 100, 50, 100, 100])
 
-    resid = psfphot.make_residual_image(data, sub_shape)
+    resid = psfphot.make_residual_image(data, psf_shape=sub_shape)
     assert_allclose(resid, 0, atol=1e-6)
 
     match = 'mode must be "new" or "all".'
@@ -1005,25 +1026,22 @@ def test_iterative_psf_photometry_mode_all():
     for col in colnames:
         assert phot3[col].unit == unit
         assert_allclose(phot3[col].value, phot[col])
-    resid_nddata = psfphotu.make_residual_image(nddata, fit_shape)
+    resid_nddata = psfphotu.make_residual_image(nddata, psf_shape=fit_shape)
     assert isinstance(resid_nddata, NDData)
     assert resid_nddata.unit == unit
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_iterative_psf_photometry_overlap():
     """
     Regression test for #1769.
 
     A ValueError should not be raised for no overlap.
     """
-    sigma = 1.5
-    psf_model = IntegratedGaussianPRF(flux=1, sigma=sigma)
-    data, true_params = make_psf_model_image((150, 150), psf_model,
-                                             n_sources=300,
-                                             model_shape=(11, 11),
-                                             flux=(50, 100),
-                                             min_separation=1, seed=0)
+    fwhm = 3.5
+    psf_model = CircularGaussianPRF(flux=1, fwhm=fwhm)
+    data, _ = make_psf_model_image((150, 150), psf_model, n_sources=300,
+                                   model_shape=(11, 11), flux=(50, 100),
+                                   min_separation=1, seed=0)
     noise = make_noise_image(data.shape, mean=0, stddev=0.01, seed=0)
     data += noise
     error = np.abs(noise)
@@ -1031,20 +1049,51 @@ def test_iterative_psf_photometry_overlap():
     data = data[slc]
     error = error[slc]
 
-    daofinder = DAOStarFinder(threshold=0.5, fwhm=sigma)
-    grouper = SourceGrouper(min_separation=3.0 * sigma)
-    psfphot = IterativePSFPhotometry(psf_model, fit_shape=(5, 5),
+    daofinder = DAOStarFinder(threshold=0.5, fwhm=fwhm)
+    grouper = SourceGrouper(min_separation=1.3 * fwhm)
+    fitter = TRFLSQFitter()
+    fit_shape = (5, 5)
+    sub_shape = fit_shape
+    psfphot = IterativePSFPhotometry(psf_model, fit_shape=fit_shape,
                                      finder=daofinder, mode='all',
-                                     grouper=grouper, maxiters=3,
-                                     aperture_radius=3)
-    with pytest.warns(AstropyUserWarning):
+                                     grouper=grouper, maxiters=2,
+                                     sub_shape=sub_shape,
+                                     aperture_radius=3, fitter=fitter)
+    match = r'One or more .* may not have converged'
+    with pytest.warns(AstropyUserWarning, match=match):
         phot = psfphot(data, error=error)
         assert len(phot) == 38
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
+def test_iterative_psf_photometry_subshape():
+    """
+    A ValueError should not be raised if sub_shape=None and the model
+    does not have a bounding box.
+    """
+    fwhm = 3.5
+    psf_model = CircularGaussianPRF(flux=1, fwhm=fwhm)
+    data, _ = make_psf_model_image((150, 150), psf_model, n_sources=30,
+                                   model_shape=(11, 11), flux=(50, 100),
+                                   min_separation=1, seed=0)
+
+    daofinder = DAOStarFinder(threshold=0.5, fwhm=fwhm)
+    grouper = SourceGrouper(min_separation=1.3 * fwhm)
+    fitter = TRFLSQFitter()
+    fit_shape = (5, 5)
+    sub_shape = None
+    psf_model.bounding_box = None
+    psfphot = IterativePSFPhotometry(psf_model, fit_shape=fit_shape,
+                                     finder=daofinder, mode='all',
+                                     grouper=grouper, maxiters=2,
+                                     sub_shape=sub_shape,
+                                     aperture_radius=3, fitter=fitter)
+    match = r'model_shape must be specified .* does not have a bounding_box'
+    with pytest.raises(ValueError, match=match):
+        psfphot(data)
+
+
 def test_iterative_psf_photometry_inputs():
-    psf_model = IntegratedGaussianPRF(flux=1, sigma=2.7 / 2.35)
+    psf_model = CircularGaussianPRF(flux=1, fwhm=2.7)
     fit_shape = (5, 5)
     finder = DAOStarFinder(10.0, 2.0)
 
@@ -1072,7 +1121,6 @@ def test_iterative_psf_photometry_inputs():
                                    aperture_radius=4, maxiters=3.14)
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_negative_xy():
     sources = Table()
     sources['id'] = np.arange(3) + 1
@@ -1081,7 +1129,7 @@ def test_negative_xy():
     sources['y_0'] = [-0.3, -0.4, 18.7]
     sources['sigma'] = 3.1
     shape = (31, 31)
-    psf_model = IntegratedGaussianPRF(flux=1, sigma=3.1)
+    psf_model = CircularGaussianPRF(flux=1, fwhm=3.1)
     data = make_model_image(shape, psf_model, sources)
     fit_shape = (11, 11)
     psfphot = PSFPhotometry(psf_model, fit_shape, aperture_radius=10)
@@ -1090,7 +1138,6 @@ def test_negative_xy():
     assert_equal(phot['y_init'], sources['y_0'])
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_out_of_bounds_centroids():
     sources = Table()
     sources['id'] = np.arange(8) + 1
@@ -1100,7 +1147,7 @@ def test_out_of_bounds_centroids():
     sources['sigma'] = 3.1
 
     shape = (51, 51)
-    psf_model = IntegratedGaussianPRF(flux=1, sigma=3.1)
+    psf_model = CircularGaussianPRF(flux=1, fwhm=3.1)
     data = make_model_image(shape, psf_model, sources)
     fit_shape = (11, 11)
     psfphot = PSFPhotometry(psf_model, fit_shape, aperture_radius=10)
@@ -1113,7 +1160,6 @@ def test_out_of_bounds_centroids():
     assert np.any(np.isnan(phot['cfit']))
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_make_psf_model():
     normalize = False
     sigma = 3.0
@@ -1160,9 +1206,8 @@ def test_make_psf_model():
                      tbl4['flux_fit'][0]), (xval, yval, flux))
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 def test_move_column():
-    psf_model = IntegratedGaussianPRF(flux=1, sigma=2.7 / 2.35)
+    psf_model = CircularGaussianPRF(flux=1, fwhm=2.7)
     fit_shape = (5, 5)
     finder = DAOStarFinder(6.0, 2.0)
     psfphot = PSFPhotometry(psf_model, fit_shape, finder=finder,
