@@ -35,6 +35,9 @@ def test_cutout():
 
     assert_equal(cutout.xyorigin, np.array((23, 88)))
 
+    cutouts2 = CutoutImage(data, yxpos, np.array(shape))
+    assert cutouts2.input_shape == shape
+
     assert f'Shape: {shape}' in repr(cutout)
     assert f'Shape: {shape}' in str(cutout)
 
@@ -43,16 +46,17 @@ def test_cutout_partial_overlap():
     data = make_100gaussians_image()
     shape = (24, 57)
 
-    # mode = 'trim'
+    # 'trim' mode
     cutout = CutoutImage(data, (11, 10), shape)
     assert cutout.input_shape == shape
     assert cutout.shape == (23, 39)
 
-    # mode = 'strict'
-    with pytest.raises(PartialOverlapError):
+    # 'strict' mode
+    match = 'Arrays overlap only partially'
+    with pytest.raises(PartialOverlapError, match=match):
         CutoutImage(data, (11, 10), shape, mode='strict')
 
-    # mode = 'partial'
+    # 'partial' mode
     cutout = CutoutImage(data, (11, 10), shape, mode='partial')
     assert cutout.input_shape == shape
     assert cutout.shape == shape
