@@ -3,8 +3,6 @@
 Tests for the depths module.
 """
 
-import itertools
-
 import astropy.units as u
 import numpy as np
 import pytest
@@ -15,13 +13,12 @@ from numpy.testing import assert_allclose
 
 from photutils.datasets import make_100gaussians_image
 from photutils.segmentation import SourceFinder, make_2dgaussian_kernel
-from photutils.utils._optional_deps import HAS_SCIPY, HAS_SKIMAGE
+from photutils.utils._optional_deps import HAS_SKIMAGE
 from photutils.utils.depths import ImageDepth
 
 bool_vals = (True, False)
 
 
-@pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
 @pytest.mark.skipif(not HAS_SKIMAGE, reason='skimage is required')
 class TestImageDepth:
     def setup_class(self):
@@ -37,8 +34,8 @@ class TestImageDepth:
         self.data = data
         self.mask = segment_map.make_source_mask()
 
-    @pytest.mark.parametrize(('units', 'overlap'),
-                             list(itertools.product(bool_vals, bool_vals)))
+    @pytest.mark.parametrize('units', bool_vals)
+    @pytest.mark.parametrize('overlap', bool_vals)
     def test_image_depth(self, units, overlap):
         radius = 4
         depth = ImageDepth(radius, nsigma=5.0, napers=100, niters=2,
@@ -79,7 +76,8 @@ class TestImageDepth:
                            progress_bar=False)
         mask = np.zeros(self.data.shape)
         mask[:, 20:] = True
-        with pytest.raises(ValueError):
+        match = 'Too many apertures for given unmasked area'
+        with pytest.raises(ValueError, match=match):
             depth(self.data, mask)
 
         depth = ImageDepth(radius, nsigma=5.0, napers=250, niters=2,
@@ -87,7 +85,8 @@ class TestImageDepth:
                            progress_bar=False)
         mask = np.zeros(self.data.shape)
         mask[:, 100:] = True
-        with pytest.warns(AstropyUserWarning, match='Unable to generate'):
+        match = r'Unable to generate .* non-overlapping apertures'
+        with pytest.warns(AstropyUserWarning, match=match):
             depth(self.data, mask)
 
         # test for zero non-overlapping apertures before slow loop
@@ -97,7 +96,8 @@ class TestImageDepth:
                            progress_bar=False)
         mask = np.zeros(self.data.shape)
         mask[:, 40:] = True
-        with pytest.warns(AstropyUserWarning, match='Unable to generate'):
+        match = r'Unable to generate .* non-overlapping apertures'
+        with pytest.warns(AstropyUserWarning, match=match):
             depth(self.data, mask)
 
     def test_zero_data(self):
@@ -106,8 +106,8 @@ class TestImageDepth:
                            overlap=True, seed=123, progress_bar=False)
         data = np.zeros((300, 400))
         mask = None
-        with pytest.warns(AstropyUserWarning,
-                          match='One or more flux_limit values was zero'):
+        match = 'One or more flux_limit values was zero'
+        with pytest.warns(AstropyUserWarning, match=match):
             limits = depth(data, mask)
             assert_allclose(limits, (0.0, np.inf))
 
@@ -118,21 +118,25 @@ class TestImageDepth:
         data = np.zeros(self.data.shape)
         mask = np.zeros(data.shape, dtype=bool)
         mask[:, 10:] = True
-        with pytest.raises(ValueError):
+        match = 'There are no unmasked pixel values'
+        with pytest.raises(ValueError, match=match):
             depth(data, mask)
 
     def test_inputs(self):
-        with pytest.raises(ValueError):
+        match = 'aper_radius must be > 0'
+        with pytest.raises(ValueError, match=match):
             ImageDepth(0.0, nsigma=5.0, napers=500, niters=2,
                        overlap=True, seed=123, zeropoint=23.9,
                        progress_bar=False)
 
-        with pytest.raises(ValueError):
+        match = 'aper_radius must be > 0'
+        with pytest.raises(ValueError, match=match):
             ImageDepth(-12.4, nsigma=5.0, napers=500, niters=2,
                        overlap=True, seed=123, zeropoint=23.9,
                        progress_bar=False)
 
-        with pytest.raises(ValueError):
+        match = 'mask_pad must be >= 0'
+        with pytest.raises(ValueError, match=match):
             ImageDepth(12.4, nsigma=5.0, napers=500, niters=2,
                        mask_pad=-7.1, overlap=True, seed=123, zeropoint=23.9,
                        progress_bar=False)
